Index: trunk/MagicSoft/Mars/Changelog
===================================================================
--- trunk/MagicSoft/Mars/Changelog	(revision 2831)
+++ trunk/MagicSoft/Mars/Changelog	(revision 2832)
@@ -18,4 +18,6 @@
 
    * mcalib/MCalibrationCalc.cc
+   * mcalib/MCalibrationPix.cc
+   * mcalib/MCalibrationCam.cc
      - fixed the warns and errs in fLog's
 
Index: trunk/MagicSoft/Mars/mcalib/MCalibrationCalc.cc
===================================================================
--- trunk/MagicSoft/Mars/mcalib/MCalibrationCalc.cc	(revision 2831)
+++ trunk/MagicSoft/Mars/mcalib/MCalibrationCalc.cc	(revision 2832)
@@ -424,5 +424,5 @@
 
 
-  *fLog << GetDescriptor() << ": Cut Histogram Edges" << endl;
+  *fLog << inf << GetDescriptor() << ": Cut Histogram Edges" << endl;
 
   //
@@ -436,5 +436,5 @@
   MCalibrationBlindPix &blindpixel = *(fCalibrations->GetBlindPixel());
 
-  *fLog << GetDescriptor() << ": Fitting the Blind Pixel" << endl;
+  *fLog << inf << GetDescriptor() << ": Fitting the Blind Pixel" << endl;
 
   // 
@@ -454,5 +454,5 @@
     }
   
-  *fLog << GetDescriptor() << ": Fitting the Normal Pixels" << endl;
+  *fLog << inf << GetDescriptor() << ": Fitting the Normal Pixels" << endl;
 
   //
@@ -500,5 +500,5 @@
     return kTRUE;
   
-  *fLog << endl;
+  *fLog << inf << endl;
   *fLog << dec << setfill(' ') << fCosmics << " Events presumably cosmics" << endl;
 
Index: trunk/MagicSoft/Mars/mcalib/MCalibrationCam.cc
===================================================================
--- trunk/MagicSoft/Mars/mcalib/MCalibrationCam.cc	(revision 2831)
+++ trunk/MagicSoft/Mars/mcalib/MCalibrationCam.cc	(revision 2832)
@@ -248,6 +248,6 @@
   int id = 0;
   
-  *fLog << "Succesfully calibrated pixels:" << endl;
-  *fLog << endl;
+  *fLog << all << "Succesfully calibrated pixels:" << endl;
+  *fLog << all << endl;
 
   TIter Next(fPixels);
@@ -263,6 +263,6 @@
             rsigma = TMath::Sqrt(rsigma);
 
-	  *fLog << pix->GetPixId() << " Pedestals: " << pix->GetPed() << " +- " << pix->GetPedRms() 
-		<< " Reduced Charge: " << pix->GetCharge() << " +- " 
+	  *fLog << all << pix->GetPixId() << " Pedestals: " << pix->GetPed() << " +- " 
+                << pix->GetPedRms() << " Reduced Charge: " << pix->GetCharge() << " +- " 
 		<< pix->GetSigmaCharge() << " Reduced Sigma: " << rsigma 
                 << " Nr Phe's: " << pix->GetPheFFactorMethod() << endl;
@@ -271,10 +271,10 @@
     }
   
-  *fLog << id << " succesful pixels :-))" << endl;
+  *fLog << all << id << " succesful pixels :-))" << endl;
   id = 0;
   
-  *fLog << endl;
-  *fLog << "Pixels with errors:" << endl;
-  *fLog << endl;
+  *fLog << all << endl;
+  *fLog << all << "Pixels with errors:" << endl;
+  *fLog << all << endl;
   
   TIter Next2(fPixels);
@@ -289,11 +289,11 @@
               rsigma = TMath::Sqrt(rsigma);
             
-            *fLog << pix->GetPixId() << " Pedestals: " << pix->GetPed() << " +- " << pix->GetPedRms() 
-                  << " Reduced Charge: " << pix->GetCharge() << " +- " 
-		<< pix->GetSigmaCharge() << " Reduced Sigma: " << rsigma << endl;
+            *fLog << all << pix->GetPixId() << " Pedestals: " << pix->GetPed() << " +- " 
+                  << pix->GetPedRms() << " Reduced Charge: " << pix->GetCharge() << " +- " 
+                  << pix->GetSigmaCharge() << " Reduced Sigma: " << rsigma << endl;
             id++;
           }
       }
-    *fLog << id << " pixels with errors :-((" << endl;
+    *fLog << all << id << " pixels with errors :-((" << endl;
     
 }
@@ -455,7 +455,8 @@
   fNumPhotInsidePlexiglassAvailable = kTRUE;
 
-  *fLog << endl;
-  *fLog << mean << " Mean number of Photons for an Inner Pixel: " << fMeanPhotInsidePlexiglass << endl;
-  *fLog << endl;
+  *fLog << inf << endl;
+  *fLog << inf << mean << " Mean number of Photons for an Inner Pixel (inside Plexiglass): " 
+        << fMeanPhotInsidePlexiglass << endl;
+  *fLog << inf << endl;
 
   TIter Next(fPixels);
@@ -510,4 +511,9 @@
 
   fNumPhotOutsidePlexiglassAvailable = kTRUE;
+
+  *fLog << inf << endl;
+  *fLog << inf << mean << " Mean number of Photons for an Inner Pixel (outside Plexiglass): " 
+        << fMeanPhotOutsidePlexiglass << endl;
+  *fLog << inf << endl;
 
   TIter Next(fPixels);
Index: trunk/MagicSoft/Mars/mcalib/MCalibrationPix.cc
===================================================================
--- trunk/MagicSoft/Mars/mcalib/MCalibrationPix.cc	(revision 2831)
+++ trunk/MagicSoft/Mars/mcalib/MCalibrationPix.cc	(revision 2832)
@@ -178,5 +178,5 @@
     fHist->SetLowerFitRange(1.5*fPedRms);
   else
-    *fLog << warn << "Cannot set lower fit range: Pedestals not available" << endl;
+    *fLog << warn << "WARNING: Cannot set lower fit range: Pedestals not available" << endl;
 
   //
@@ -193,5 +193,5 @@
       if(!fHist->FitChargeLoGain())
 	{
-	  *fLog << warn << "Could not fit Lo Gain charges of pixel " << fPixId << endl;
+	  *fLog << warn << "WARNING: Could not fit Lo Gain charges of pixel " << fPixId << endl;
           //          
           // 5) In case of failure print out the fit results
@@ -207,5 +207,5 @@
       if(!fHist->FitChargeHiGain())
 	{
-	  *fLog << warn << "Could not fit Hi Gain charges of pixel " << fPixId << endl;
+	  *fLog << warn << "WARNING: Could not fit Hi Gain charges of pixel " << fPixId << endl;
           //          
           // 5) In case of failure print out the fit results
@@ -227,5 +227,5 @@
   if (fCharge <= 0.)
     {
       *fLog << warn << "Cannot apply calibration: Mean Fitted Charges are smaller than 0 in pixel " 
             << fPixId << endl;
       return kFALSE;
@@ -308,5 +308,6 @@
       if (fRSigmaSquare <= 0.)
         {
-          *fLog << warn << "Cannot apply F-Factor calibration: Reduced Sigma smaller than 0 in pixel " 
+          *fLog << warn 
+                << "WARNING: Cannot apply F-Factor calibration: Reduced Sigma smaller than 0 in pixel " 
                 << fPixId << endl;
           if (fHiGainSaturation)
@@ -439,4 +440,17 @@
 
 
+//
+// The check returns kTRUE if:
+//
+// 
+//
+Bool_t MCalibrationPix::CheckOscillations()
+{
+
+
+  return kTRUE;
+}
+
+
 
 void MCalibrationPix::ApplyLoGainConversion()
@@ -492,5 +506,5 @@
       if(!fHist->FitTimeLoGain())
 	{
-	  *fLog << warn << "Could not fit Lo Gain times of pixel " << fPixId << endl;
+	  *fLog << warn << "WARNING: Could not fit Lo Gain times of pixel " << fPixId << endl;
 	  fHist->PrintTimeFitResult();
 	  return kFALSE;
@@ -505,5 +519,5 @@
       if(!fHist->FitTimeHiGain())
 	{
-	  *fLog << warn << "Could not fit Hi Gain times of pixel " << fPixId << endl;
+	  *fLog << warn << "WARNING: Could not fit Hi Gain times of pixel " << fPixId << endl;
 	  fHist->PrintTimeFitResult();
 	  return kFALSE;
@@ -227,5 +227,5 @@
   if (fCharge <= 0.)
     {
-      *fLog << warn << "Cannot apply calibration: Mean Fitted Charges are smaller than 0 in pixel " 
+      *fLog << warn << "WARNING: Cannot apply calibration: Mean Fitted Charges are smaller than 0 in pixel " 
             << fPixId << endl;
       return kFALSE;
